From 074b2d1b5894f12fae78a569ea507612616663ff Mon Sep 17 00:00:00 2001
From: Jari Vetoniemi <mailroxas@gmail.com>
Date: Sat, 17 Jan 2015 18:53:29 +0200
Subject: Remove --backend and --prioritory options, change prioritory ->
 priorty and provide BEMENU_BACKEND env variable. Change API to reflect this
 change.

There is no reliable way to detect when running on terminal (especially
when stdin is a pipe), so we need to make curses backend explicit with
BEMENU_BACKEND=curses or bm_menu_new("curses"), otherwise GUI backend
will be choosed automatically.
---
 lib/internal.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'lib/internal.h')

diff --git a/lib/internal.h b/lib/internal.h
index 112e7bd..7b71eb4 100644
--- a/lib/internal.h
+++ b/lib/internal.h
@@ -93,10 +93,10 @@ struct render_api {
     const char *version;
 
     /**
      * Prioritory of the plugin.
      * Terminal renderers should be first, then graphicals.
      */
-    enum bm_prioritory prioritory;
+    enum bm_priorty priorty;
 };
 
 /**
@@ -93,10 +93,10 @@ struct render_api {
 
     /**
-     * Prioritory of the plugin.
+     * Priorty of the plugin.
      * Terminal renderers should be first, then graphicals.
      */
-- 
cgit v1.2.3-70-g09d2